Documentation
¶
Index ¶
- Constants
- func CompactIfName(name, prefix, suffix string) string
- func ConfigureVtep(sw *models.Switch, port *models.SwitchPort, encapIfindex int, ...) (vxlan *netlink.Vxlan, err error)
- func EnsureNetns(name string) (netns.NsHandle, *netlink.Handle, error)
- func PrepareDhcpNetns(zone *models.DHCPZone, name string) (veth *netlink.Veth, err error)
Constants ¶
const ( DHCP_SERVER_PORT = 67 DHCP_IFNAME = "dhcp0" )
const ( VXLAN_PORT = 4789 VXLAN_TTL = 5 )
const MAX_LENGTH = unix.IFNAMSIZ - 1
Variables ¶
This section is empty.
Functions ¶
func CompactIfName ¶
func ConfigureVtep ¶
func ConfigureVtep( sw *models.Switch, port *models.SwitchPort, encapIfindex int, encapAddr netip.Addr, ) (vxlan *netlink.Vxlan, err error)
Create and configure a Linux VXLAN interface using a multicast group address and VNI derived from the logical switch name.
func EnsureNetns ¶
Create a netns and return a netlink socket to interacting with it.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.